@@ -3,6 +3,7 @@ from jinja2 import PackageLoader
 import sys
 import os
 from pkg_resources import iter_entry_points
+import json
 
 
 # Frame's library path
@@ -22,7 +23,9 @@ config = DotDict({
 		'directory': 'templates',
 		'loaders': [PackageLoader('frame', 'templates')],
 		'globals': {},
-		'filters': {}
+		'filters': {},
+    'environment': {},
+    'extension': '.html'
 	},
 	
 	'preprocessors': [
@@ -34,10 +37,13 @@ config = DotDict({
 	
 	'postprocessors': [
 		'handle_head_request',
-		'add_last_modified'
+		'add_last_modified',
+		'add_date'
 	],
 	
 	'hooks': [],
+
+  'init_hooks': [],
 	
 	'timezone': 'America/Los_Angeles',
 	
@@ -62,7 +68,7 @@ config = DotDict({
 	
 	'frame': {
 		'path': __frame_path,
-		'version': '0.1a',
+		'version': '0.2a',
 	},
 	
 	'http_server': {
@@ -72,9 +78,13 @@ config = DotDict({
 	'response': {
 		'default_headers': {
 			'Content-Type': 'text/html',
-			'Server': 'Frame/0.1a',
+			'Server': 'Frame/0.2a',
 		}
-	}
+	},
+
+  'jsonify': {
+    'encoder': json.JSONEncoder
+  }
 })
 
 
