@@ -1,5 +1,5 @@
 from _routes import routes
-from _app import app
+import _app
 from errors import Error301, Error302, Error303
 
 
@@ -50,7 +50,7 @@ class Controller(object):
 	
 	__metaclass__ = _ControllerMeta
 	
-	app = app
+	app = _app.app
 	'''The current Frame application'''
 
 	def redirect(self, url, add_script_name=True, status='302 Found'):
@@ -74,13 +74,6 @@ class Controller(object):
 		
 		raise error
 
-	@property
-	def get_template(self):
-		'''
-		Alias of Jinja2 environment's get_template method (fetch a Jinja2 template).
-		'''
-		return self.app.environment.get_template
-
 	"""
 	@property
 	def response(self):
@@ -96,17 +89,10 @@ class Controller(object):
 		Retrieve the current :mod:`frame.request.Request` object.
 		'''
 		return app.request
-
-	@property
-	def session(self):
-		'''
-		Retrieve the current :mod:`frame.session.Session` object.
-		'''
-		return app.session
 		
 	@property
 	def uri(self):
 		'''
 		Get a list containing the URI elements, separated on '/'.
 		'''
-		return self.request.headers.path_info.strip('/').split('/')
\ No newline at end of file
+		return self.request.headers.path_info.strip('/').split('/')
