@@ -10,6 +10,7 @@ from threading import RLock
 import time
 import datetime
 import json
+from _config import config
 
 
 class Decorator(object):
@@ -205,7 +206,7 @@ def jsonify(require_content_type=False):
 					and kwargs['content_type'] == 'json'):
 			
 				app.response.headers['Content-Type'] = 'application/json'
-				return json.dumps(f(*args, **kwargs))
+				return json.dumps(f(*args, **kwargs), cls=config.jsonify.encoder)
 				
 			else:
 				return f(*args, **kwargs)
@@ -251,4 +252,52 @@ class Pagination(object):
 	def pages(self):
 		pages = {}
 		for i in xrange(1, self.num_pages + 1):
-			yield {'num': i, 'selected': i == self.page}
\ No newline at end of file
+			yield {'num': i, 'selected': i == self.page}
+
+
+class Hook(object):
+  def __init__(self, app, controller):
+    self.app = app
+    self.controller = controller
+
+
+def import_all_from_folder(path, excludes=[]):
+  import os
+  import sys
+  from importlib import import_module
+  from glob import glob
+
+  modules = {}
+  base_path = os.path.dirname(path)
+
+  if not os.path.exists(base_path):
+    raise ImportError("Cannot import modules from %s. Path does not exist." % abs_path)
+
+  add_path = base_path not in sys.path
+		
+  if add_path:
+    sys.path.append(base_path)
+
+  for file_path in glob('%s/*.py' % base_path):
+    dir_name, file_name = os.path.split(file_path)
+    module_name = file_name[:-3]
+    modules[module_name] = import_module(module_name)
+
+  if add_path:
+    sys.path.remove(base_path)
+
+  return modules
+
+
+class MethodException(Exception):
+  def __init__(self, action, params={}, *args, **kwargs):
+    import _app
+    import response
+
+    if not action.im_self:
+      obj = action.im_class()
+      action = getattr(obj, action.__name__)
+
+    self.response = response.Response(_app.app, action, params)
+
+    Exception.__init__(self, *args, **kwargs)
